@@ -2,7 +2,7 @@ __author__ = "hugo.inzirillo"
 
 from abc import ABCMeta, abstractmethod
 
-from napoleontoolbox.authentication import PasswordCredentials, ClientCredentials
+from napoleontoolbox.bifrost import PasswordCredentials, ClientCredentials
 from napoleontoolbox.napoleon_config_tools import getter, config
 
 
