@@ -438,20 +438,22 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     ohlc_bnb_min_binance = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time, symbol ='BNBUSDT', aggreg ='1m')
 
     fut_transfers = binance_get_futures_transfer_histo(public_key, private_key, start_time, end_time)
-    fut_transfers['date'] = fut_transfers['date'].dt.floor('H')
-    fut_transfers = pd.merge(fut_transfers, ohlc_bnb_min_binance[['ts', 'open']], how='left', left_on='date',
+    if fut_transfers is not None:
+        fut_transfers['date'] = fut_transfers['date'].dt.floor('H')
+        fut_transfers = pd.merge(fut_transfers, ohlc_bnb_min_binance[['ts', 'open']], how='left', left_on='date',
                                right_on='ts')
 
-    def convert_trans_bnb_to_usdt(row):
-        print(row)
-        if row['asset'] == 'BNB':
-            return float(row['amount']) * float(row['open'])
-        elif row['asset'] == 'USDT':
-            return float(row['amount'])
-        else :
-            return np.nan
-    fut_transfers['fut_transfer_usdt_amount'] = fut_transfers.apply(convert_trans_bnb_to_usdt, axis=1)
-    fut_transfers = fut_transfers[['date','fut_transfer_usdt_amount']].groupby('date').sum()
+        def convert_trans_bnb_to_usdt(row):
+            print(row)
+            if row['asset'] == 'BNB':
+                return float(row['amount']) * float(row['open'])
+            elif row['asset'] == 'USDT':
+                return float(row['amount'])
+            else :
+                return np.nan
+        fut_transfers['fut_transfer_usdt_amount'] = fut_transfers.apply(convert_trans_bnb_to_usdt, axis=1)
+        fut_transfers = fut_transfers[['date','fut_transfer_usdt_amount']].groupby('date').sum()
+
 
 
     history_balance = binance_get_future_balance_history(public_key,private_key,start_time, end_time)
@@ -498,11 +500,12 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
         dbx.upload(fullname=full_path, folder='', subfolder='', name=balance_pkl_file_name, overwrite=True)
         os.remove(full_path)
 
-        full_path = local_root_directory + transfer_pkl_file_name
-        fut_transfers.to_pickle(full_path)
-        print(f'uploading to dropbox {full_path}')
-        dbx.upload(fullname=full_path, folder='', subfolder='', name=transfer_pkl_file_name, overwrite=True)
-        os.remove(full_path)
+        if fut_transfers is not None:
+            full_path = local_root_directory + transfer_pkl_file_name
+            fut_transfers.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=transfer_pkl_file_name, overwrite=True)
+            os.remove(full_path)
 
 
         full_path = local_root_directory + trade_pkl_file_name
@@ -659,17 +662,20 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
 
     wh['date'] = wh.index
-    wh['bench'] = 1.
-    fut_transfers_old = fut_transfers.copy()
-    fut_transfers = pd.merge(fut_transfers, wh[['date', 'bench']], how='outer', left_on='date', right_on='date')
-    fut_transfers = fut_transfers.sort_values(by='date')
-    fut_transfers['fut_transfer_usdt_amount'] = fut_transfers['fut_transfer_usdt_amount'].shift()
-    fut_transfers = fut_transfers.dropna()
-    fut_transfers = fut_transfers.drop(columns=['bench'])
+    if fut_transfers is not None:
+        wh['bench'] = 1.
+        fut_transfers_old = fut_transfers.copy()
+        fut_transfers = pd.merge(fut_transfers, wh[['date', 'bench']], how='outer', left_on='date', right_on='date')
+        fut_transfers = fut_transfers.sort_values(by='date')
+        fut_transfers['fut_transfer_usdt_amount'] = fut_transfers['fut_transfer_usdt_amount'].shift()
+        fut_transfers = fut_transfers.dropna()
+        fut_transfers = fut_transfers.drop(columns=['bench'])
+        wh = wh.drop(columns=['bench'])
+        wh = pd.merge(wh, fut_transfers, how='left', left_on='date', right_on='date')
+        wh['fut_transfer_usdt_amount'] = wh['fut_transfer_usdt_amount'].fillna(0.)
+    else :
+        wh['fut_transfer_usdt_amount'] = 0
 
-    wh = wh.drop(columns=['bench'])
-    wh = pd.merge(wh, fut_transfers, how='left', left_on='date', right_on='date')
-    wh['fut_transfer_usdt_amount'] = wh['fut_transfer_usdt_amount'].fillna(0.)
     wh = pd.merge(wh, converted_history_balance, how='left', left_on='date', right_on ='ts')
 
     wh = wh.rename(columns={"convertedWalletBalance": "wallet_balance"})
@@ -678,7 +684,10 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     while np.isnan(wh.at[wh.index[starting_index], 'wallet_balance']) == True:
         starting_index = starting_index + 1
 
+
     wh.at[wh.index[starting_index], 'realized_pnl'] = wh.at[wh.index[starting_index], 'wallet_balance']
+    wh.at[wh.index[starting_index], 'fut_transfer_usdt_amount'] = 0.
+
 
     wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
     wh['valuation'] = wh.net_profit + wh.fut_transfer_usdt_amount
@@ -688,15 +697,17 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
     wh = wh.drop(columns=['fut_transfer_usdt_amount'])
     td = pd.merge(td, wh, how='left', left_on='date', right_on='date')
+    if fut_transfers_old is not None:
+        td['bench'] = 1.
 
-    td['bench'] = 1.
+        fut_transfers_old = pd.merge(fut_transfers_old, td[['date', 'bench']], how='outer', left_on='date', right_on='date')
+        fut_transfers_old = fut_transfers_old.sort_values(by='date')
+        fut_transfers_old['fut_transfer_usdt_amount'] = fut_transfers_old['fut_transfer_usdt_amount'].shift()
+        fut_transfers_old = fut_transfers_old.dropna()
 
-    fut_transfers_old = pd.merge(fut_transfers_old, td[['date', 'bench']], how='outer', left_on='date', right_on='date')
-    fut_transfers_old = fut_transfers_old.sort_values(by='date')
-    fut_transfers_old['fut_transfer_usdt_amount'] = fut_transfers_old['fut_transfer_usdt_amount'].shift()
-    fut_transfers_old = fut_transfers_old.dropna()
-
-    td = pd.merge(td, fut_transfers_old, how='left', left_on='date', right_on='date')
+        td = pd.merge(td, fut_transfers_old, how='left', left_on='date', right_on='date')
+    else:
+        td['fut_transfer_usdt_amount'] = 0.
 
 
     td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
